{% extends "imagestore/base.html" %}
{% load i18n %}
{% load thumbnail %}


{% block title %}
    {% trans "Upload image" %}
{% endblock %}

{% block head %}
    {{ block.super }}
    <script src="{{ STATIC_URL }}autocomplete.js"></script>
    <script>
        $(function(){
            completeField('#id_tags', '{% url imagestore:autocomplete "tag" %}');
            completeField('#id_place_text', '{% url imagestore:autocomplete "place" %}');
        })
    </script>
{% endblock %}

{% block imagestore-breadcrumb %}
    <li>{% trans "Upload image" %}</li>
{% endblock %}

{% block content %}
    <h1>{% trans "Upload image" %}</h1>
    <form action="." method="post" enctype="multipart/form-data" class='upload-image'>
    {% csrf_token %}
    {{ form.as_p }}
    <input type="submit" value="{% trans "Upload" %}" class='btn success'>
    </form>
{% endblock content %}