{% extends "imagestore/base.html" %}

{% load i18n %}

{% block content %}
    <p>{% trans "Are you sure that you would like to delete this image?" %}</p>
    <form method="post" action=".">
        {% csrf_token %}
        <p>
            <a class='btn' href="{{ post.get_absolute_url }}">← {% trans "No, take me back" %}</a>
            <input type="submit" class='btn danger' value="{% trans 'Yes, I am sure' %}" />
        </p>
    </form>
{% endblock %}