{% load i18n %}
{% load thumbnail %}

<div class="user-info">
    <h2>{% trans "User" %}</h2>
    <div class="avatar">
            <a href="{{ profile.get_absolute_url }}">
            {% thumbnail profile.avatar "80x80" as avatar %}
                <img src="{{ avatar.url }}" alt="avatar">
            {% empty %}
            {% endthumbnail %}
            </a>
    </div>
    <div class="user-name">
        <a href="{{ profile.get_absolute_url }}">
            {{ profile.user.username }}
        </a>
    </div>
 </div>
